@@ -1,4 +1,4 @@
-//@line 41 "/builds/slave/firefox-lorentz-linux-xulrunner/build/toolkit/components/console/jsconsole-clhandler.js"
+//@line 41 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/components/console/jsconsole-clhandler.js"
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
@@ -25,14 +25,10 @@ jsConsoleHandler.prototype = {
       cmdLine.preventDefault = true;
   },
 
-  helpInfo : "  -jsconsole           Open the Error console.\n",
+  helpInfo : "  -jsconsole         Open the Error console.\n",
 
-  classDescription: "jsConsoleHandler",
   classID: Components.ID("{2cd0c310-e127-44d0-88fc-4435c9ab4d4b}"),
-  contractID: "@mozilla.org/toolkit/console-clh;1",
   QueryInterface: XPCOMUtils.generateQI([Ci.nsICommandLineHandler]),
-  _xpcom_categories: [{category: "command-line-handler", entry: "b-jsconsole"}]
 };
 
-function NSGetModule(compMgr, fileSpec)
-  XPCOMUtils.generateModule([jsConsoleHandler]);
+var NSGetFactory = XPCOMUtils.generateNSGetFactory([jsConsoleHandler]);
