@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 38 "/builds/slave/m-192-lnx-xr/build/toolkit/mozapps/update/src/nsUpdateServiceStub.js"
+//@line 38 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/mozapps/update/nsUpdateServiceStub.js"
 */
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/FileUtils.jsm");
@@ -11,13 +11,16 @@ const DIR_UPDATES         = "updates";
 const FILE_UPDATE_STATUS  = "update.status";
 
 const KEY_APPDIR          = "XCurProcD";
-//@line 53 "/builds/slave/m-192-lnx-xr/build/toolkit/mozapps/update/src/nsUpdateServiceStub.js"
+
+//@line 56 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/mozapps/update/nsUpdateServiceStub.js"
+
+//@line 60 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/mozapps/update/nsUpdateServiceStub.js"
 
 /**
-//@line 61 "/builds/slave/m-192-lnx-xr/build/toolkit/mozapps/update/src/nsUpdateServiceStub.js"
+//@line 68 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/mozapps/update/nsUpdateServiceStub.js"
  */
 function getUpdateDirNoCreate(pathArray) {
-//@line 72 "/builds/slave/m-192-lnx-xr/build/toolkit/mozapps/update/src/nsUpdateServiceStub.js"
+//@line 77 "/builds/moz2_slave/2.0-lnx-xr/build/toolkit/mozapps/update/nsUpdateServiceStub.js"
   return FileUtils.getDir(KEY_APPDIR, pathArray, false);
 }
 
@@ -33,12 +36,9 @@ function UpdateServiceStub() {
   }
 }
 UpdateServiceStub.prototype = {
-  classDescription: "Update Service Stub",
-  contractID: "@mozilla.org/updates/update-service-stub;1",
+  observe: function(){},
   classID: Components.ID("{e43b0010-04ba-4da6-b523-1f92580bc150}"),
-  _xpcom_categories: [{ category: "profile-after-change" }],
-  QueryInterface: XPCOMUtils.generateQI([])
+  QueryInterface: XPCOMUtils.generateQI([Ci.nsIObserver])
 };
 
-function NSGetModule(compMgr, fileSpec)
-  XPCOMUtils.generateModule([UpdateServiceStub]);
+var NSGetFactory = XPCOMUtils.generateNSGetFactory([UpdateServiceStub]);
