@@ -34,32 +34,19 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 38 "/builds/slave/192-lnx-xr/build/xulrunner/app/xulrunner.js"
+//@line 38 "/builds/moz2_slave/2.0-linuxqt-xr/build/xulrunner/app/xulrunner.js"
 
 // We need to override the default values of these preferences since all.js
-// assumes these are in the navigator package, which for us is non-existant.
+// assumes these are in the navigator package, which for us is nonexistent.
 // XXX(darin): perhaps all.js should not be seamonkey specific
 pref("general.useragent.locale", "en-US");
-pref("font.language.group", "chrome://global/locale/intl.properties");
-pref("intl.accept_languages", "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.static", "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more1",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more2",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more3",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more4",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.more5",  "chrome://global/locale/intl.properties");
-pref("intl.charsetmenu.browser.unicode",  "UTF-8, UTF-16LE, UTF-16BE, UTF-32, UTF-32LE, UTF-32BE");
-pref("intl.charset.detector", "chrome://global/locale/intl.properties");
-pref("intl.charset.default",  "chrome://global-platform/locale/intl.properties");
-pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.properties");
-pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
 pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul");
 pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul");
 pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager");
 pref("xpinstall.dialog.progress.type.skin", "Extension:Manager");
 pref("xpinstall.enabled", true);
-//@line 65 "/builds/slave/192-lnx-xr/build/xulrunner/app/xulrunner.js"
+//@line 52 "/builds/moz2_slave/2.0-linuxqt-xr/build/xulrunner/app/xulrunner.js"
 pref("browser.preferences.instantApply", true);
-//@line 70 "/builds/slave/192-lnx-xr/build/xulrunner/app/xulrunner.js"
+//@line 57 "/builds/moz2_slave/2.0-linuxqt-xr/build/xulrunner/app/xulrunner.js"
 pref("browser.preferences.animateFadeIn", false);
