@@ -1,4 +1,6 @@
-//@line 37 "/builds/slave/192-lnx-xr/build/toolkit/mozapps/extensions/content/blocklist.js"
+//@line 37 "/builds/slave/m-2.0-lnx-xr/build/toolkit/mozapps/extensions/content/blocklist.js"
+
+Components.utils.import("resource://gre/modules/Services.jsm");
 
 var gArgs;
 
@@ -9,9 +11,8 @@ function init() {
 
   // NOTE: We use strings from the "updates.properties" bundleset to change the
   // text on the "Cancel" button to "Restart Later". (bug 523784)
-  let strings = Components.classes["@mozilla.org/intl/stringbundle;1"].
-                getService(Components.interfaces.nsIStringBundleService);
-  let bundle = strings.createBundle("chrome://mozapps/locale/update/updates.properties");
+  let bundle = Services.strings.
+              createBundle("chrome://mozapps/locale/update/updates.properties");
   let cancelButton = document.documentElement.getButton("cancel");
   cancelButton.setAttribute("label", bundle.GetStringFromName("restartLaterButton"));
   cancelButton.setAttribute("accesskey",
