@@ -1,4 +1,4 @@
-//@line 43 "/builds/slave/192-lnx-xr/build/toolkit/components/passwordmgr/content/passwordManager.js"
+//@line 43 "/builds/moz2_slave/2.0-linuxqt-xr/build/toolkit/components/passwordmgr/content/passwordManager.js"
 
 /*** =================== SAVED SIGNONS CODE =================== ***/
 
@@ -66,7 +66,7 @@ var signonsTreeView = {
 function LoadSignons() {
   // loads signons into table
   try {
-    signons = passwordmanager.getAllLogins({});
+    signons = passwordmanager.getAllLogins();
   } catch (e) {
     signons = [];
   }
@@ -187,7 +187,7 @@ function FinalizeSignonDeletions(syncNeeded) {
   // See bug 405389.
   if (syncNeeded) {
     try {
-      signons = passwordmanager.getAllLogins({});
+      signons = passwordmanager.getAllLogins();
     } catch (e) {
       signons = [];
     }
@@ -329,3 +329,21 @@ function _filterPasswords()
 
   document.getElementById("signonsIntro").textContent = kSignonBundle.getString("loginsSpielFiltered");
 }
+
+function CopyPassword() {
+  // Copy selected signon's password to clipboard
+  var clipboard = Components.classes["@mozilla.org/widget/clipboardhelper;1"].
+                  getService(Components.interfaces.nsIClipboardHelper);
+  var row = document.getElementById("signonsTree").currentIndex;
+  var password = signonsTreeView.getCellText(row, {id : "passwordCol" });
+  clipboard.copyString(password);
+}
+
+function UpdateCopyPassword() {
+  var singleSelection = (signonsTreeView.selection.count == 1);
+  var menuitem = document.getElementById("context-copypassword");
+  if (singleSelection)
+    menuitem.removeAttribute("disabled");
+  else
+    menuitem.setAttribute("disabled", "true");
+}
